package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.FeignService;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.UserRequest;
import com.bwie.common.domain.response.UserResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;

@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private FeignService feignService;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    @Autowired
    private HttpServletRequest request;

    @Override
    public Result<UserResponse> login(UserRequest userRequest) {
        if(StringUtils.isAllBlank(userRequest.getUserName(),userRequest.getPassword())){
            return Result.error("为空");
        }

        Result<User> data = feignService.user(userRequest);
        User user = data.getData();

        if(null == user){
            return Result.error("为空");
        }

        String key = UUID.randomUUID().toString().replaceAll("-", "");
        HashMap<String, Object> hashMap = new HashMap<>();
        hashMap.put(JwtConstants.USER_KEY,key);
        String token = JwtUtils.createToken(hashMap);

        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY + key , JSONObject.toJSONString(user));

        UserResponse userResponse = new UserResponse();
        userResponse.setExpiredTime("1Hour");
        userResponse.setToken(token);

        return Result.success(userResponse);
    }

    @Override
    public User userInfo() {
        String userKey = request.getHeader(TokenConstants.TOKEN);
        String token = JwtUtils.getUserKey(userKey);
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + token);
        return JSONObject.parseObject(s,User.class);
    }

    @Override
    public void logout() {
        String userKey = request.getHeader(TokenConstants.TOKEN);
        String token = JwtUtils.getUserKey(userKey);
        redisTemplate.delete(TokenConstants.LOGIN_TOKEN_KEY + token);
    }
}
