package com.bwie.costType.controller;

import com.bwie.common.domain.CostType;
import com.bwie.common.domain.Project;
import com.bwie.common.domain.ProjectCostType;
import com.bwie.common.result.Result;
import com.bwie.costType.service.impl.CostTypeServiceImpl;
import com.bwie.costType.service.impl.ProjectCostTypeServiceImpl;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@Log4j2
public class ProjectCostTypeController {
    @Autowired
    private ProjectCostTypeServiceImpl projectCostTypeService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 根据项目id获取成本类型中间列表
     * @return
     */
    @GetMapping("/ProjectCostTypeListById/{pid}")
    public Result<List<ProjectCostType>> ProjectCostTypeListById(@PathVariable Integer pid){
        log.info("功能：成根据项目id获取成本类型中间列表类型，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),pid);

        Result<List<ProjectCostType>> result = projectCostTypeService.ProjectCostTypeListById(pid);

        log.info("功能：根据项目id获取成本类型中间列表，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 修改估算金额
     */
    @PostMapping("updateImputedAmount")
    public Result updateImputedAmount(@RequestBody Project project){
        log.info("功能：修改估算金额，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),project);

        Result result = projectCostTypeService.updateImputedAmount(project);

        log.info("功能：修改估算金额，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }

    /**
     * 审核估算金额
     * @param projectCostType
     * @return
     */
    @PostMapping("examineImputedAmount")
    public Result examineImputedAmount(@RequestBody ProjectCostType projectCostType){
        log.info("功能：审核估算金额，请求路径：{}，请求方式：{}，请求参数：{}",
                request.getRequestURI(),request.getMethod(),projectCostType);

        Result result = projectCostTypeService.examineImputedAmount(projectCostType);

        log.info("功能：审核估算金额，请求路径：{}，请求方式：{}，响应结果：{}",
                request.getRequestURI(),request.getMethod(),result);

        return result;
    }



}
