package com.bwie.costType.service.impl;

import com.bwie.common.domain.Project;
import com.bwie.common.domain.ProjectCostType;
import com.bwie.common.result.Result;
import com.bwie.costType.mapper.ProjectCostTypeMapper;
import com.bwie.costType.service.ProjectCostTypeService;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.UUID;

@Service
public class ProjectCostTypeServiceImpl implements ProjectCostTypeService {
    @Autowired
    private ProjectCostTypeMapper projectCostTypeMapper;

    @Autowired
    private RabbitTemplate rabbitTemplate;

    /**
     * 根据用户id获取成本类型中间列表
     * @param pid
     * @return
     */
    @Override
    public Result<List<ProjectCostType>> ProjectCostTypeListById(Integer pid) {
        List<ProjectCostType> list = projectCostTypeMapper.ProjectCostTypeListById(pid);
        return Result.success(list);
    }

    /**
     * 修改估算金额
     * @param project
     * @return
     */
    @Override
    public Result updateImputedAmount(Project project) {
        List<ProjectCostType> projectCostTypeList = project.getProjectCostTypeList();
        for (ProjectCostType projectCostType : projectCostTypeList) {
            //先进行数据的修改
            projectCostTypeMapper.updateImputedAmount(projectCostType);
            //判断 如果概算金额不为空 说明已经审核过了，需要发送消息给审核人
            if (projectCostType.getEstimatedAmount()!=null){
                //[项目名称][类型名称]的估算类型发估算更改，金额从[原始金额]变更为[变更后金额]
                String msg = project.getProjectName()+projectCostType.getCostTypeName()+
                        "的估算类型发生估算更改，金额从"+projectCostType.getImputedAmount()+
                        "变更为"+projectCostType.getEstimatedAmount();
                Integer updateBy = projectCostType.getUpdateBy();  //获取当前最后修改人也就是审核人id
                //异步发送消息
                rabbitTemplate.convertAndSend("MSG_QUEUE",msg+"%"+updateBy,message -> {
                    message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                    return message;
                });
            }
        }
        return Result.success();
    }

    /**
     * 审核估算金额/填写概算金额
     * @param projectCostType
     * @return
     */
    @Override
    public Result examineImputedAmount(ProjectCostType projectCostType) {
        if (projectCostType.getEstimatedAmount().equals(projectCostType.getImputedAmount())){
            projectCostType.setStatus(1);
        }else {
            projectCostType.setStatus(0);
        }
        int i = projectCostTypeMapper.examineImputedAmount(projectCostType);
        return i>0?Result.success():Result.error();
    }
}
