package com.bwie.project.service.impl;

import com.bwie.common.domain.Project;
import com.bwie.common.domain.ProjectCostType;
import com.bwie.common.domain.request.ProjectInquire;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.project.feign.FeignCostType;
import com.bwie.project.mapper.ProjectMapper;
import com.bwie.project.service.ProjectService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author sikadi
 * @since 2023-10-08 02:57:22
 */
@Service
public class ProjectServiceImpl implements ProjectService {

    @Autowired
    private ProjectMapper projectMapper;

    @Autowired
    private FeignCostType feignCostType;


    /**
     * @description: 列表
     * @author: (扭曲)(爬行)(抽搐)
     * @date: 2023/10/8 16:42
     * @param: [projectInquire]
     * @return: com.bwie.common.result.PageResult
     **/
    @Override
    public PageResult projectList(ProjectInquire projectInquire) {
        // 分页
        PageHelper.startPage(projectInquire.getPageNum(),projectInquire.getPageSize());
        // 查询列表
        List<Project> projectList = projectMapper.projectList(projectInquire);

        // 查询成功时 循环获取id
        projectList.forEach(item -> {
            // 创建两个空的对象 分别装的是 总概算金额 总估算金额
            Double imputedAmountSum = null; // 总概算金额
            Double estimatedAmountSum = null; // 总估算金额
            // 赋值给 中间表
            Result<List<ProjectCostType>> listResult = feignCostType.ProjectCostTypeListById(item.getId());
            // 循环得出值
            for (ProjectCostType datum : listResult.getData()) {
                imputedAmountSum += datum.getImputedAmount();
                estimatedAmountSum += datum.getEstimatedAmount();
            }
            // 赋值
            item.setImputedAmountSum(imputedAmountSum);
            item.setEstimatedAmountSum(estimatedAmountSum);
        });
        // 取出
        PageInfo<Project> projectPageInfo = new PageInfo<>(projectList);

        return PageResult.toPageResult(projectPageInfo.getTotal(),projectList);
    }

    /**
     * @description: 添加
     * @author: (扭曲)(爬行)(抽搐)
     * @date: 2023/10/9 8:16
     * @param: [project]
     * @return: com.bwie.common.result.Result
     **/
    @Override
    public Result projectIncrease(Project project){
        // 先进行 表添加
        int i = projectMapper.projectIncrease(project);
        if(0==i){
            return Result.error("添加失败");
        }
        // 再次进行添加成本类型中间表
        int j = projectMapper.projectCostTypeIncrease(project);
        return null;
    }
}
